import"./registerWidgets.75ad232d.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="72e1af60-8313-4bae-98ab-41ff1860fc58",x._sentryDebugIdIdentifier="sentry-dbid-72e1af60-8313-4bae-98ab-41ff1860fc58")}catch{}})();const f=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{f as u};
//# sourceMappingURL=uuid.e8567429.js.map
