import{q as r,a,b as i,t as c,f as p,g as d,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.75ad232d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b77a09d0-97fa-48f2-8f0b-9a576965692e",e._sentryDebugIdIdentifier="sentry-dbid-b77a09d0-97fa-48f2-8f0b-9a576965692e")}catch{}})();const I={};function x(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.6032ad94.js"),["assets/Player.6032ad94.js","assets/index.6150da77.js","assets/registerWidgets.75ad232d.js","assets/registerWidgets.448db7e9.css","assets/uuid.e8567429.js","assets/broker.e9e43f98.js","assets/passwordlessManager.e427d83f.js","assets/pubsub.98e48b80.js","assets/icons.79136e9f.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.94563a79.js","assets/Passwordless.fbe1299e.js","assets/CircularLoading.a5d89224.js","assets/lottie.24c4e251.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.86ac0c56.css","assets/executeJs.36329e9a.js","assets/PlayerNavbar.f4ffe1a1.js","assets/PlayerNavbar.adff8b48.css","assets/WidgetsFrame.151ac7b7.js","assets/colors.55a42b18.js","assets/WidgetsFrame.701a818b.css","assets/Modal.5f99340f.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/broker.5f3abad8.css","assets/DashPlayer.c53462c5.js","assets/runnerData.f94f315b.js","assets/DashPlayer.ef4a798d.css","assets/asyncComputed.62fdaa3d.js","assets/Player.20a058fa.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{const e=u({render:()=>f(A)});l.init(),e.use(o),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,o),s(e,v),s(e,w),s(e,k)};D();
//# sourceMappingURL=player.e43f5741.js.map
