import{S as m}from"./Sidebar.4b13feb0.js";import{N as d}from"./Navbar.1ea28550.js";import{E as p,F as l,G as b}from"./icons.79136e9f.js";import{d as u,K as _,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.75ad232d.js";import{a as h}from"./asyncComputed.62fdaa3d.js";import"./gateway.5777efa2.js";import{O}from"./organization.0c2d53ac.js";import"./index.7d53b731.js";import"./Tooltip.b14b5f10.js";import"./logo.084e5d7c.js";import"./passwordlessManager.e427d83f.js";import"./pubsub.98e48b80.js";import"./activeRecord.91b12e0f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7bb60431-1ebd-416f-a5a7-5b5e5f90be7c",e._sentryDebugIdIdentifier="sentry-dbid-7bb60431-1ebd-416f-a5a7-5b5e5f90be7c")}catch{}})();const x={class:"organization"},k=u({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=_(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:b,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(d,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(m,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const R=I(k,[["__scopeId","data-v-7eef90b7"]]);export{R as default};
//# sourceMappingURL=Organization.92087b9d.js.map
