import{v as s}from"./icons.79136e9f.js";import{d as r,a as d,b as c,c as i,e as _,z as l,U as u,q as f}from"./registerWidgets.75ad232d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a4afd757-8350-42ab-a842-e52d59d156ee",e._sentryDebugIdIdentifier="sentry-dbid-a4afd757-8350-42ab-a842-e52d59d156ee")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=d("icon");return c(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(o,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const v=f(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.75ccb1c4.js.map
