import{P as r}from"./Passwordless.fbe1299e.js";import{N as a}from"./Navbar.1ea28550.js";import{d as i,b as d,c,e as t,H as p,q as _}from"./registerWidgets.75ad232d.js";import{M as m}from"./member.dfae94e3.js";import"./CircularLoading.a5d89224.js";import"./lottie.24c4e251.js";import"./icons.79136e9f.js";import"./passwordlessManager.e427d83f.js";import"./pubsub.98e48b80.js";import"./logo.084e5d7c.js";import"./asyncComputed.62fdaa3d.js";import"./gateway.5777efa2.js";import"./activeRecord.91b12e0f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="774b10c2-7383-4e6a-960a-7d184f573f9e",e._sentryDebugIdIdentifier="sentry-dbid-774b10c2-7383-4e6a-960a-7d184f573f9e")}catch{}})();const f={class:"login"},l=i({__name:"Login",setup(e){const o=p();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(d(),c("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const B=_(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.c2fb77fb.js.map
