import{q as t,b as a,c as s}from"./registerWidgets.75ad232d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4967a137-8a7a-4536-a906-8d77fa37260f",e._sentryDebugIdIdentifier="sentry-dbid-4967a137-8a7a-4536-a906-8d77fa37260f")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return a(),s("div",r,"Organization settings")}const c=t(o,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.26bc0ef9.js.map
