import{L as a}from"./lottie.24c4e251.js";import{d as t,r,o as s,b as c,c as d,x as i,B as _,q as f}from"./registerWidgets.75ad232d.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="1b958cc0-3cfb-469f-97f8-a9c6ea62857c",n._sentryDebugIdIdentifier="sentry-dbid-1b958cc0-3cfb-469f-97f8-a9c6ea62857c")}catch{}})();const l={class:"container"},u=t({__name:"LoadingIndicator",setup(n){const e=r(null);return s(()=>{!e.value||a.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(c(),d("div",l,[i("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const g=f(u,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.bb348770.js.map
