import{M as a}from"./Modal.5f99340f.js";import{d as r,v as c,r as d,b as _,c as l,e as n,w as i,F as f,a as b,x as m,q as u}from"./registerWidgets.75ad232d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1b6708e6-2b86-4e5e-a5b2-9cdb7a3716a0",e._sentryDebugIdIdentifier="sentry-dbid-1b6708e6-2b86-4e5e-a5b2-9cdb7a3716a0")}catch{}})();const p=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=b("router-view");return _(),l(f,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:i(()=>[m("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const I=u(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.332fb1b8.js.map
